==> dianara_1.2.3.orig.tar.gz: dianara-v1.2.3/src/mainwindow.h <==
/*
 *   This file is part of Dianara
 *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H


#include <QMainWindow>
#include <QApplication>
#include <QSettings>
#include <QMenuBar>
#include <QToolBar>
#include <QStatusBar>
#include <QSystemTrayIcon>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QToolBox>
#include <QTabWidget>
#include <QLabel>
#include <QCloseEvent>
#include <QByteArray>
#include <QPixmap>
#include <QMessageBox>
#include <QDir>
#include <QTimer>
#include <QScrollArea>
#include <QScrollBar>
#include <QVariantList>
#include <QDesktopServices>
#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
#include <QStandardPaths>
#endif
#include <QTime>
#include <QSplitter>
#include <QPainter>

#include <QDebug>

#include "accountdialog.h"
#include "configdialog.h"
#include "pumpcontroller.h"
#include "notifications.h"
#include "publisher.h"
#include "timeline.h"
#include "post.h"
#include "contactmanager.h"
#include "minorfeed.h"
#include "profileeditor.h"
#include "filtereditor.h"
#include "filterchecker.h"
#include "logviewer.h"
#include "helpwidget.h"
#include "groupsmanager.h"

#include "globalobject.h"


class MainWindow : public QMainWindow
{
    Q_OBJECT


public:    
    MainWindow(QWidget *parent = 0);
    ~MainWindow();

    void prepareDataDirectory();
    void createMenus();
    void createToolbar();
    void createStatusbarWidgets();
    void createTrayIcon();
    void setTrayIconPixmap(int count = 0);

    void loadSettings();
    void saveSettings();


public slots:
    void updateUserID(QString newUserID);
    void updateConfigSettings();

    void toggleWidgetsByAuthorization(bool authorized);

    void postInit();

    void trayControl(QSystemTrayIcon::ActivationReason reason);
    void showTrayFallbackMessage(QString title, QString message);

    void updateProfileData(QString avatarUrl, QString fullName,
                           QString hometown, QString bio,
                           QString eMail);

    void updateAllTimelines();
    void updateMainDirectMinorTimelines();
    void updateMainActivityMinorTimelines();

    void scrollMainTimelineTo(QAbstractSlider::SliderAction sliderAction);
    void scrollDirectTimelineTo(QAbstractSlider::SliderAction sliderAction);
    void scrollActivityTimelineTo(QAbstractSlider::SliderAction sliderAction);
    void scrollFavoritesTimelineTo(QAbstractSlider::SliderAction sliderAction);

    void scrollMainTimelineToWidget(QWidget *widget);
    void scrollDirectTimelineToWidget(QWidget *widget);
    void scrollActivityTimelineToWidget(QWidget *widget);
    void scrollFavoritesTimelineToWidget(QWidget *widget);

    void notifyTimelineUpdate(int timelineType,
                              int newPostCount,
                              int highlightCount);
    void setTimelineTabTitle(int timelineType,
                             int newPostCount,
                             int highlightCount,
                             int totalItemsCount);

    void setTitleAndTrayInfo(int currentTab);
    void setMinorFeedTitle(int newItemsCount, int newHighlightedItemsCount);
    void notifyMinorFeedUpdate(int newItemsCount, int highlightedCount);

    void storeAvatar(QByteArray avatarData, QUrl avatarUrl);
    void storeImage(QByteArray imageData, QUrl imageUrl);

    void setStatusBarMessage(QString message);
    void setTransientStatusMessage(QString message);

    void markAllAsRead();
    void refreshAllTimestamps();
    void adjustTimelineSizes();
    void onSplitterMoved();


    void toggleSidePanel(bool shown);
    void toggleToolbar(bool shown);
    void toggleStatusBar(bool shown);
    void toggleFullscreen(bool enabled);


    void visitWebSite();
    void visitFAQ();
    void visitTips();
    void visitUserList();
    void aboutDianara();

    void toggleMainWindow();

    void showAuthError(QString title, QString message);

    void quitProgram();


protected:
    virtual void closeEvent(QCloseEvent *event);
    virtual void resizeEvent(QResizeEvent *event);


private:
    ////////////////////////////////////// Menus
    QMenu *sessionMenu;
    QMenu *viewMenu;
    QMenu *settingsMenu;
    QMenu *helpMenu;

    QMenu *trayContextMenu;
    QAction *trayShowWindowAction;

    QAction *sessionUpdateMainTimeline;
    QAction *sessionUpdateDirectTimeline;
    QAction *sessionUpdateActivityTimeline;
    QAction *sessionUpdateFavoritesTimeline;
    QAction *sessionUpdateMinorFeed;
    QAction *sessionUpdateAllTimelines;
    QAction *sessionMarkAllAsRead;
    QAction *sessionPostNote;
    QAction *sessionQuit;

    QAction *viewSidePanel;
    QAction *viewToolbar;
    QAction *viewStatusBar;
    QAction *viewFullscreenAction;
    QAction *viewLogAction;

    QAction *settingsEditProfile;
    QAction *settingsAccount;
    QAction *settingsFilters;
    QAction *settingsConfigure;

    QAction *helpBasicHelp;
    QAction *helpVisitWebsite;
    QAction *helpVisitPumpFAQ;
    QAction *helpVisitPumpTips;
    QAction *helpVisitPumpUserList;
    QAction *helpAbout;
    ////////////////////////////////////// End menus

    // Toolbar
    QToolBar *mainToolBar;

    // Statusbar widgets
    QToolButton *statusLogButton;


    QSplitter *mainSplitter;

    QWidget *leftSideWidget;
    QVBoxLayout *leftLayout;

    QHBoxLayout *leftTopLayout;
    QVBoxLayout *userInfoLayout;
    QToolBox *leftPanel;

    QWidget *rightSideWidget;
    QVBoxLayout *rightLayout;
    QTabWidget *tabWidget;
    int tabsPosition;
    bool tabsMovable;

    // User profile widgets
    QPushButton *avatarIconButton;
    QString avatarURL;
    QLabel *fullNameLabel;
    QLabel *userIdLabel;
    QLabel *userHometownLabel;


    QSystemTrayIcon *trayIcon;
    bool trayIconAvailable;
    int trayIconType;
    QPixmap trayCustomPixmap;
    int trayCurrentCount;


    GlobalObject *globalObject;

    AccountDialog *accountDialog;
    ProfileEditor *profileEditor;
    ConfigDialog *configDialog;
    FilterChecker *filterChecker;
    FilterEditor *filterEditor;
    LogViewer *logViewer;
    HelpWidget *helpWidget;
    PumpController *pumpController;
    FDNotifications *fdNotifier;

    MinorFeed *meanwhileFeed;

    int postsPerPageMain;
    TimeLine *mainTimeline;
    QScrollArea *mainTimelineScrollArea;

    int postsPerPageOther;
    TimeLine *directTimeline;
    QScrollArea *directTimelineScrollArea;

    TimeLine *activityTimeline;
    QScrollArea *activityTimelineScrollArea;

    TimeLine *favoritesTimeline;
    QScrollArea *favoritesTimelineScrollArea;


    ContactManager *contactManager;

    Publisher *publisher;


    bool firstRun;
    QString dataDirectory; // will have /images and /avatars
    bool reallyQuitProgram;

    int updateInterval;
    QTimer *updateTimer;

    QTimer *timestampsTimer;
    QTimer *delayedResizeTimer;

    QTimer *postInitTimer;

    bool publicPosts;

    QString oldStatusBarMessage;

    // user account-related data
    QString userID;

};

#endif // MAINWINDOW_H

==> dianara-v1.2.4.tar.gz: dianara-v1.2.4/src/mainwindow.h <==
/*
 *   This file is part of Dianara
 *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H


#include <QMainWindow>
#include <QApplication>
#include <QSettings>
#include <QMenuBar>
#include <QToolBar>
#include <QStatusBar>
#include <QSystemTrayIcon>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QToolBox>
#include <QTabWidget>
#include <QLabel>
#include <QCloseEvent>
#include <QByteArray>
#include <QPixmap>
#include <QMessageBox>
#include <QDir>
#include <QTimer>
#include <QScrollArea>
#include <QScrollBar>
#include <QVariantList>
#include <QDesktopServices>
#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
#include <QStandardPaths>
#endif
#include <QTime>
#include <QSplitter>
#include <QPainter>

#include <QDebug>

#include <iostream>

#include "accountdialog.h"
#include "configdialog.h"
#include "pumpcontroller.h"
#include "notifications.h"
#include "publisher.h"
#include "timeline.h"
#include "post.h"
#include "contactmanager.h"
#include "minorfeed.h"
#include "profileeditor.h"
#include "filtereditor.h"
#include "filterchecker.h"
#include "logviewer.h"
#include "helpwidget.h"
#include "groupsmanager.h"
#include "globalobject.h"


class MainWindow : public QMainWindow
{
    Q_OBJECT


public:    
    MainWindow(QWidget *parent = 0);
    ~MainWindow();

    void prepareDataDirectory();
    void createMenus();
    void createToolbar();
    void createStatusbarWidgets();

    enum StatusType
    {
        Initializing,
        Autoupdating,
        Stopped
    };

    void setStateIcon(StatusType statusType);
    void createTrayIcon();
    void setTrayIconPixmap(int newCount = 0, int hightlightedCount = 0);

    void loadSettings();
    void saveSettings();


public slots:
    void updateUserID(QString newUserID);
    void updateConfigSettings();

    void toggleWidgetsByAuthorization(bool authorized);

    void onInitializationComplete();

    void postInit();

    void trayControl(QSystemTrayIcon::ActivationReason reason);
    void showTrayFallbackMessage(QString title, QString message);

    void updateProfileData(QString avatarUrl, QString fullName,
                           QString hometown, QString bio,
                           QString eMail);

    void toggleAutoUpdates(bool checked);

    void updateAllTimelines();
    void updateMainDirectMinorTimelines();
    void updateMainActivityMinorTimelines();

    void scrollMainTimelineTo(QAbstractSlider::SliderAction sliderAction);
    void scrollDirectTimelineTo(QAbstractSlider::SliderAction sliderAction);
    void scrollActivityTimelineTo(QAbstractSlider::SliderAction sliderAction);
    void scrollFavoritesTimelineTo(QAbstractSlider::SliderAction sliderAction);

    void scrollMainTimelineToWidget(QWidget *widget);
    void scrollDirectTimelineToWidget(QWidget *widget);
    void scrollActivityTimelineToWidget(QWidget *widget);
    void scrollFavoritesTimelineToWidget(QWidget *widget);

    void notifyTimelineUpdate(int timelineType,
                              int newPostCount,
                              int highlightCount);
    void setTimelineTabTitle(int timelineType,
                             int newPostCount,
                             int highlightCount,
                             int totalItemsCount);

    void setTitleAndTrayInfo(int currentTab);
    void setMinorFeedTitle(int newItemsCount, int newHighlightedItemsCount);
    void notifyMinorFeedUpdate(int newItemsCount, int highlightedCount);

    void storeAvatar(QByteArray avatarData, QUrl avatarUrl);
    void storeImage(QByteArray imageData, QUrl imageUrl);

    void setStatusBarMessage(QString message);
    void setTransientStatusMessage(QString message);

    void markAllAsRead();
    void refreshAllTimestamps();
    void adjustTimelineSizes();


    void toggleSidePanel(bool shown);
    void toggleToolbar(bool shown);
    void toggleStatusBar(bool shown);
    void toggleFullscreen(bool enabled);


    void visitWebSite();
    void visitFAQ();
    void visitTips();
    void visitUserList();
    void aboutDianara();

    void toggleMainWindow();

    void showAuthError(QString title, QString message);

    void quitProgram();


protected:
    virtual void closeEvent(QCloseEvent *event);
    virtual void resizeEvent(QResizeEvent *event);


private:
    ////////////////////////////////////// Menus
    QMenu *sessionMenu;
    QMenu *viewMenu;
    QMenu *settingsMenu;
    QMenu *helpMenu;

    QMenu *trayContextMenu;
    QAction *trayTitleSeparatorAction;
    QAction *trayShowWindowAction;

    QAction *sessionUpdateMainTimeline;
    QAction *sessionUpdateDirectTimeline;
    QAction *sessionUpdateActivityTimeline;
    QAction *sessionUpdateFavoritesTimeline;
    QAction *sessionUpdateMinorFeed;
    QAction *sessionUpdateAllTimelines;
    QAction *sessionAutoUpdates;
    QAction *sessionMarkAllAsRead;
    QAction *sessionPostNote;
    QAction *sessionQuit;

    QAction *viewSidePanel;
    QAction *viewToolbar;
    QAction *viewStatusBar;
    QAction *viewFullscreenAction;
    QAction *viewLogAction;

    QAction *settingsEditProfile;
    QAction *settingsAccount;
    QAction *settingsFilters;
    QAction *settingsConfigure;

    QAction *helpBasicHelp;
    QAction *helpVisitWebsite;
    QAction *helpVisitPumpFAQ;
    QAction *helpVisitPumpTips;
    QAction *helpVisitPumpUserList;
    QAction *helpAbout;
    ////////////////////////////////////// End menus

    // Toolbar
    QToolBar *mainToolBar;

    // Statusbar widgets
    QToolButton *statusStateButton;
    QToolButton *statusLogButton;


    QSplitter *mainSplitter;

    QWidget *leftSideWidget;
    QVBoxLayout *leftLayout;

    QHBoxLayout *leftTopLayout;
    QVBoxLayout *userInfoLayout;
    QToolBox *leftPanel;

    QWidget *rightSideWidget;
    QVBoxLayout *rightLayout;
    QTabWidget *tabWidget;
    int tabsPosition;
    bool tabsMovable;

    // User profile widgets
    QPushButton *avatarIconButton;
    QString avatarURL;
    QLabel *fullNameLabel;
    QLabel *userIdLabel;
    QLabel *userHometownLabel;


    QSystemTrayIcon *trayIcon;
    bool trayIconAvailable;
    int trayIconType;
    QPixmap trayCustomPixmap;
    int trayCurrentNewCount;
    int trayCurrentHLCount;


    GlobalObject *globalObject;

    AccountDialog *accountDialog;
    ProfileEditor *profileEditor;
    ConfigDialog *configDialog;
    FilterChecker *filterChecker;
    FilterEditor *filterEditor;
    LogViewer *logViewer;
    HelpWidget *helpWidget;
    PumpController *pumpController;
    FDNotifications *fdNotifier;

    MinorFeed *meanwhileFeed;

    int postsPerPageMain;
    TimeLine *mainTimeline;
    QScrollArea *mainTimelineScrollArea;

    int postsPerPageOther;
    TimeLine *directTimeline;
    QScrollArea *directTimelineScrollArea;

    TimeLine *activityTimeline;
    QScrollArea *activityTimelineScrollArea;

    TimeLine *favoritesTimeline;
    QScrollArea *favoritesTimelineScrollArea;


    ContactManager *contactManager;

    Publisher *publisher;


    bool firstRun;
    QString dataDirectory; // will have /images and /avatars
    bool reallyQuitProgram;

    int updateInterval;
    QTimer *updateTimer;

    QTimer *timestampsTimer;
    QTimer *delayedResizeTimer;

    QTimer *postInitTimer;

    bool publicPosts;

    QString oldStatusBarMessage;

    // user account-related data
    QString userID;

};

#endif // MAINWINDOW_H
